@@ -4,7 +4,7 @@ use base qw(RDF::RDFa::Parser::Profile);
 use strict;
 use 5.008;
 
-our $VERSION = '1.09_01';
+our $VERSION = '1.09_02';
 
 BEGIN
 {
@@ -23,7 +23,10 @@ sub new
 		|| $uri =~ m'^http://gmpg.org/xfn/1'i
 		|| $uri =~ m'^http://purl.org/uF/'i
 		|| $uri eq 'http://dublincore.org/documents/2008/08/04/dc-html/'
-		|| $uri eq 'http://purl.org/NET/erdf/profile';
+		|| $uri eq 'http://purl.org/NET/erdf/profile'
+		|| $uri eq 'http://www.w3.org/1999/xhtml/vocab'
+		|| $uri eq 'http://www.w3.org/2005/10/profile'
+		;
 	
 	return undef;
 }
@@ -79,4 +82,4 @@ skos	http://www.w3.org/2004/02/skos/core#
 tag	http://www.holygoat.co.uk/owl/redwood/0.1/tags/
 xfn	http://vocab.sindice.com/xfn#
 xhv	http://www.w3.org/1999/xhtml/vocab#
-xsd	http://www.w3.org/2001/XMLSchema#
\ No newline at end of file
+xsd	http://www.w3.org/2001/XMLSchema#
